@@ -128,6 +128,7 @@ sub _delegate_to_cb_or_private {
 
     if ( my $cb = $self->$cb_method ) {
 
+		# TODO: deprecate legacy_args
         if ( my $obj = $self->legacy_args ) {
 
             # for older users of Mojolicious::Plugin::OAuth2::Server need to pass
@@ -135,7 +136,7 @@ sub _delegate_to_cb_or_private {
             for ( $method ) {
 
                 /login_resource_owner|confirm_by_resource_owner|verify_client/ && do {
-                    return $cb->( $obj, @args{ qw/ client_id scopes redirect_uri response_type / } );
+                    return $cb->( $obj, @args{ qw/ client_id scopes redirect_uri response_type client_secret / } );
                 };
 
 				$self->_uses_user_passwords && /verify_user_password/ && do {
